use Test::More;
use Lingua::EN::Inflexion;

is verb(q{find})->past, q{found}  => q{past 'find' --> 'found'};
is verb(q{gotten})->past, q{got}  => q{past 'gotten' --> 'got'};
is verb(q{lives})->past, q{lived}  => q{past 'lives' --> 'lived'};
is verb(q{sneaks})->past, q{sneaked}  => q{past 'sneaks' --> 'sneaked'};
is verb(q{dreams})->past, q{dreamed}  => q{past 'dreams' --> 'dreamed'};
is verb(q{beholding})->past, q{beheld}  => q{past 'beholding' --> 'beheld'};
is verb(q{forsaken})->past, q{forsook}  => q{past 'forsaken' --> 'forsook'};
is verb(q{meeting})->past, q{met}  => q{past 'meeting' --> 'met'};
is verb(q{upsets})->past, q{upset}  => q{past 'upsets' --> 'upset'};
is verb(q{wring})->past, q{wrung}  => q{past 'wring' --> 'wrung'};
is verb(q{quizzed})->past, q{quizzed}  => q{past 'quizzed' --> 'quizzed'};
is verb(q{rend})->past, q{rent}  => q{past 'rend' --> 'rent'};
is verb(q{wanting})->past, q{wanted}  => q{past 'wanting' --> 'wanted'};
is verb(q{leads})->past, q{led}  => q{past 'leads' --> 'led'};
is verb(q{beat})->past, q{beat}  => q{past 'beat' --> 'beat'};
is verb(q{seem})->past, q{seemed}  => q{past 'seem' --> 'seemed'};
is verb(q{bet})->past, q{bet}  => q{past 'bet' --> 'bet'};
is verb(q{won't})->past, q{wouldn't}  => q{past 'won't' --> 'wouldn't'};
is verb(q{had})->past, q{had}  => q{past 'had' --> 'had'};
is verb(q{bursting})->past, q{burst}  => q{past 'bursting' --> 'burst'};
is verb(q{costs})->past, q{cost}  => q{past 'costs' --> 'cost'};
is verb(q{feel})->past, q{felt}  => q{past 'feel' --> 'felt'};
is verb(q{run})->past, q{ran}  => q{past 'run' --> 'ran'};
is verb(q{rings})->past, q{rang}  => q{past 'rings' --> 'rang'};
is verb(q{speeds})->past, q{sped}  => q{past 'speeds' --> 'sped'};
is verb(q{eating})->past, q{ate}  => q{past 'eating' --> 'ate'};
is verb(q{swears})->past, q{swore}  => q{past 'swears' --> 'swore'};
is verb(q{staved})->past, q{staved}  => q{past 'staved' --> 'staved'};
is verb(q{psyched})->past, q{psyched}  => q{past 'psyched' --> 'psyched'};
is verb(q{withstand})->past, q{withstood}  => q{past 'withstand' --> 'withstood'};
is verb(q{drag})->past, q{dragged}  => q{past 'drag' --> 'dragged'};
is verb(q{meets})->past, q{met}  => q{past 'meets' --> 'met'};
is verb(q{wend})->past, q{wended}  => q{past 'wend' --> 'wended'};
is verb(q{dive})->past, q{dived}  => q{past 'dive' --> 'dived'};
is verb(q{kill})->past, q{killed}  => q{past 'kill' --> 'killed'};
is verb(q{leading})->past, q{led}  => q{past 'leading' --> 'led'};
is verb(q{wants})->past, q{wanted}  => q{past 'wants' --> 'wanted'};
is verb(q{found})->past, q{found}  => q{past 'found' --> 'found'};
is verb(q{strip})->past, q{stripped}  => q{past 'strip' --> 'stripped'};
is verb(q{burst})->past, q{burst}  => q{past 'burst' --> 'burst'};
is verb(q{looked})->past, q{looked}  => q{past 'looked' --> 'looked'};
is verb(q{aren't})->past, q{wasn't}  => q{past 'aren't' --> 'wasn't'};
is verb(q{smite})->past, q{smote}  => q{past 'smite' --> 'smote'};
is verb(q{interlaying})->past, q{interlaid}  => q{past 'interlaying' --> 'interlaid'};
is verb(q{laying})->past, q{laid}  => q{past 'laying' --> 'laid'};
is verb(q{interlay})->past, q{interlaid}  => q{past 'interlay' --> 'interlaid'};
is verb(q{costing})->past, q{cost}  => q{past 'costing' --> 'cost'};
is verb(q{sweeps})->past, q{swept}  => q{past 'sweeps' --> 'swept'};
is verb(q{blown})->past, q{blew}  => q{past 'blown' --> 'blew'};
is verb(q{ached})->past, q{ached}  => q{past 'ached' --> 'ached'};
is verb(q{ringing})->past, q{rang}  => q{past 'ringing' --> 'rang'};
is verb(q{smells})->past, q{smelled}  => q{past 'smells' --> 'smelled'};
is verb(q{undertakes})->past, q{undertook}  => q{past 'undertakes' --> 'undertook'};
is verb(q{leaned})->past, q{leaned}  => q{past 'leaned' --> 'leaned'};
is verb(q{overdraws})->past, q{overdrew}  => q{past 'overdraws' --> 'overdrew'};
is verb(q{iris})->past, q{irised}  => q{past 'iris' --> 'irised'};
is verb(q{held})->past, q{held}  => q{past 'held' --> 'held'};
is verb(q{begun})->past, q{began}  => q{past 'begun' --> 'began'};
is verb(q{forgotten})->past, q{forgot}  => q{past 'forgotten' --> 'forgot'};
is verb(q{wringing})->past, q{wrung}  => q{past 'wringing' --> 'wrung'};
is verb(q{hew})->past, q{hewed}  => q{past 'hew' --> 'hewed'};
is verb(q{strews})->past, q{strewed}  => q{past 'strews' --> 'strewed'};
is verb(q{overdrawn})->past, q{overdrew}  => q{past 'overdrawn' --> 'overdrew'};
is verb(q{broken})->past, q{broke}  => q{past 'broken' --> 'broke'};
is verb(q{leaps})->past, q{leapt}  => q{past 'leaps' --> 'leapt'};
is verb(q{beheld})->past, q{beheld}  => q{past 'beheld' --> 'beheld'};
is verb(q{springing})->past, q{sprang}  => q{past 'springing' --> 'sprang'};
is verb(q{is})->past, q{was}  => q{past 'is' --> 'was'};
is verb(q{withdraw})->past, q{withdrew}  => q{past 'withdraw' --> 'withdrew'};
is verb(q{stung})->past, q{stung}  => q{past 'stung' --> 'stung'};
is verb(q{sunburn})->past, q{sunburned}  => q{past 'sunburn' --> 'sunburned'};
is verb(q{withdrawing})->past, q{withdrew}  => q{past 'withdrawing' --> 'withdrew'};
is verb(q{happening})->past, q{happened}  => q{past 'happening' --> 'happened'};
is verb(q{shoes})->past, q{shod}  => q{past 'shoes' --> 'shod'};
is verb(q{wait})->past, q{waited}  => q{past 'wait' --> 'waited'};
is verb(q{lying})->past, q{lay}  => q{past 'lying' --> 'lay'};
is verb(q{sweats})->past, q{sweat}  => q{past 'sweats' --> 'sweat'};
is verb(q{tears})->past, q{tore}  => q{past 'tears' --> 'tore'};
is verb(q{doesn't})->past, q{didn't}  => q{past 'doesn't' --> 'didn't'};
is verb(q{fight})->past, q{fought}  => q{past 'fight' --> 'fought'};
is verb(q{arisen})->past, q{arose}  => q{past 'arisen' --> 'arose'};
is verb(q{beget})->past, q{begot}  => q{past 'beget' --> 'begot'};
is verb(q{hasn't})->past, q{hadn't}  => q{past 'hasn't' --> 'hadn't'};
is verb(q{was})->past, q{was}  => q{past 'was' --> 'was'};
is verb(q{wakes})->past, q{woke}  => q{past 'wakes' --> 'woke'};
is verb(q{fighting})->past, q{fought}  => q{past 'fighting' --> 'fought'};
is verb(q{slides})->past, q{slid}  => q{past 'slides' --> 'slid'};
is verb(q{gilded})->past, q{gilded}  => q{past 'gilded' --> 'gilded'};
is verb(q{leaping})->past, q{leapt}  => q{past 'leaping' --> 'leapt'};
is verb(q{lies})->past, q{lay}  => q{past 'lies' --> 'lay'};
is verb(q{give})->past, q{gave}  => q{past 'give' --> 'gave'};
is verb(q{don't})->past, q{didn't}  => q{past 'don't' --> 'didn't'};
is verb(q{saws})->past, q{sawed}  => q{past 'saws' --> 'sawed'};
is verb(q{awakes})->past, q{awoke}  => q{past 'awakes' --> 'awoke'};
is verb(q{rive})->past, q{rived}  => q{past 'rive' --> 'rived'};
is verb(q{liking})->past, q{liked}  => q{past 'liking' --> 'liked'};
is verb(q{staves})->past, q{staved}  => q{past 'staves' --> 'staved'};
is verb(q{risen})->past, q{rose}  => q{past 'risen' --> 'rose'};
is verb(q{shoeing})->past, q{shod}  => q{past 'shoeing' --> 'shod'};
is verb(q{avalanches})->past, q{avalanched}  => q{past 'avalanches' --> 'avalanched'};
is verb(q{smiting})->past, q{smote}  => q{past 'smiting' --> 'smote'};
is verb(q{catches})->past, q{caught}  => q{past 'catches' --> 'caught'};
is verb(q{bent})->past, q{bent}  => q{past 'bent' --> 'bent'};
is verb(q{crept})->past, q{crept}  => q{past 'crept' --> 'crept'};
is verb(q{sunburning})->past, q{sunburned}  => q{past 'sunburning' --> 'sunburned'};
is verb(q{watched})->past, q{watched}  => q{past 'watched' --> 'watched'};
is verb(q{help})->past, q{helped}  => q{past 'help' --> 'helped'};
is verb(q{tearing})->past, q{tore}  => q{past 'tearing' --> 'tore'};
is verb(q{riding})->past, q{rode}  => q{past 'riding' --> 'rode'};
is verb(q{moving})->past, q{moved}  => q{past 'moving' --> 'moved'};
is verb(q{spoiled})->past, q{spoilt}  => q{past 'spoiled' --> 'spoilt'};
is verb(q{flies})->past, q{flew}  => q{past 'flies' --> 'flew'};
is verb(q{psyche})->past, q{psyched}  => q{past 'psyche' --> 'psyched'};
is verb(q{upsetting})->past, q{upset}  => q{past 'upsetting' --> 'upset'};
is verb(q{stink})->past, q{stank}  => q{past 'stink' --> 'stank'};
is verb(q{abided})->past, q{abided}  => q{past 'abided' --> 'abided'};
is verb(q{happened})->past, q{happened}  => q{past 'happened' --> 'happened'};
is verb(q{swum})->past, q{swam}  => q{past 'swum' --> 'swam'};
is verb(q{misunderstands})->past, q{misunderstood}  => q{past 'misunderstands' --> 'misunderstood'};
is verb(q{seeking})->past, q{sought}  => q{past 'seeking' --> 'sought'};
is verb(q{knows})->past, q{knew}  => q{past 'knows' --> 'knew'};
is verb(q{running})->past, q{ran}  => q{past 'running' --> 'ran'};
is verb(q{begotten})->past, q{begot}  => q{past 'begotten' --> 'begot'};
is verb(q{undergone})->past, q{underwent}  => q{past 'undergone' --> 'underwent'};
is verb(q{watches})->past, q{watched}  => q{past 'watches' --> 'watched'};
is verb(q{shits})->past, q{shat}  => q{past 'shits' --> 'shat'};
is verb(q{clinging})->past, q{clung}  => q{past 'clinging' --> 'clung'};
is verb(q{undertaken})->past, q{undertook}  => q{past 'undertaken' --> 'undertook'};
is verb(q{talk})->past, q{talked}  => q{past 'talk' --> 'talked'};
is verb(q{speaking})->past, q{spoke}  => q{past 'speaking' --> 'spoke'};
is verb(q{drive})->past, q{drove}  => q{past 'drive' --> 'drove'};
is verb(q{overtake})->past, q{overtook}  => q{past 'overtake' --> 'overtook'};
is verb(q{foretelling})->past, q{foretold}  => q{past 'foretelling' --> 'foretold'};
is verb(q{foretell})->past, q{foretold}  => q{past 'foretell' --> 'foretold'};
is verb(q{bending})->past, q{bent}  => q{past 'bending' --> 'bent'};
is verb(q{douching})->past, q{douched}  => q{past 'douching' --> 'douched'};
is verb(q{falls})->past, q{fell}  => q{past 'falls' --> 'fell'};
is verb(q{am})->past, q{was}  => q{past 'am' --> 'was'};
is verb(q{sunburns})->past, q{sunburned}  => q{past 'sunburns' --> 'sunburned'};
is verb(q{shedding})->past, q{shed}  => q{past 'shedding' --> 'shed'};
is verb(q{speak})->past, q{spoke}  => q{past 'speak' --> 'spoke'};
is verb(q{shown})->past, q{showed}  => q{past 'shown' --> 'showed'};
is verb(q{moves})->past, q{moved}  => q{past 'moves' --> 'moved'};
is verb(q{rides})->past, q{rode}  => q{past 'rides' --> 'rode'};
is verb(q{shave})->past, q{shaved}  => q{past 'shave' --> 'shaved'};
is verb(q{runs})->past, q{ran}  => q{past 'runs' --> 'ran'};
is verb(q{leaving})->past, q{left}  => q{past 'leaving' --> 'left'};
is verb(q{lost})->past, q{lost}  => q{past 'lost' --> 'lost'};
is verb(q{proving})->past, q{proved}  => q{past 'proving' --> 'proved'};
is verb(q{spent})->past, q{spent}  => q{past 'spent' --> 'spent'};
is verb(q{shake})->past, q{shook}  => q{past 'shake' --> 'shook'};
is verb(q{drunk})->past, q{drank}  => q{past 'drunk' --> 'drank'};
is verb(q{likes})->past, q{liked}  => q{past 'likes' --> 'liked'};
is verb(q{happen})->past, q{happened}  => q{past 'happen' --> 'happened'};
is verb(q{bets})->past, q{bet}  => q{past 'bets' --> 'bet'};
is verb(q{seeks})->past, q{sought}  => q{past 'seeks' --> 'sought'};
is verb(q{knowing})->past, q{knew}  => q{past 'knowing' --> 'knew'};
is verb(q{cling})->past, q{clung}  => q{past 'cling' --> 'clung'};
is verb(q{haven't})->past, q{hadn't}  => q{past 'haven't' --> 'hadn't'};
is verb(q{spring})->past, q{sprang}  => q{past 'spring' --> 'sprang'};
is verb(q{won})->past, q{won}  => q{past 'won' --> 'won'};
is verb(q{beholds})->past, q{beheld}  => q{past 'beholds' --> 'beheld'};
is verb(q{waking})->past, q{woke}  => q{past 'waking' --> 'woke'};
is verb(q{stinking})->past, q{stank}  => q{past 'stinking' --> 'stank'};
is verb(q{bends})->past, q{bent}  => q{past 'bends' --> 'bent'};
is verb(q{falling})->past, q{fell}  => q{past 'falling' --> 'fell'};
is verb(q{swung})->past, q{swung}  => q{past 'swung' --> 'swung'};
is verb(q{knitting})->past, q{knitted}  => q{past 'knitting' --> 'knitted'};
is verb(q{swell})->past, q{swelled}  => q{past 'swell' --> 'swelled'};
is verb(q{laid})->past, q{laid}  => q{past 'laid' --> 'laid'};
is verb(q{driving})->past, q{drove}  => q{past 'driving' --> 'drove'};
is verb(q{stolen})->past, q{stole}  => q{past 'stolen' --> 'stole'};
is verb(q{dragged})->past, q{dragged}  => q{past 'dragged' --> 'dragged'};
is verb(q{forgiven})->past, q{forgave}  => q{past 'forgiven' --> 'forgave'};
is verb(q{means})->past, q{meant}  => q{past 'means' --> 'meant'};
is verb(q{bound})->past, q{bound}  => q{past 'bound' --> 'bound'};
is verb(q{psyches})->past, q{psyched}  => q{past 'psyches' --> 'psyched'};
is verb(q{lose})->past, q{lost}  => q{past 'lose' --> 'lost'};
is verb(q{saw})->past, q{sawed}  => q{past 'saw' --> 'sawed'};
is verb(q{lie})->past, q{lay}  => q{past 'lie' --> 'lay'};
is verb(q{abides})->past, q{abided}  => q{past 'abides' --> 'abided'};
is verb(q{brought})->past, q{brought}  => q{past 'brought' --> 'brought'};
is verb(q{living})->past, q{lived}  => q{past 'living' --> 'lived'};
is verb(q{clapped})->past, q{clapped}  => q{past 'clapped' --> 'clapped'};
is verb(q{flying})->past, q{flew}  => q{past 'flying' --> 'flew'};
is verb(q{thriving})->past, q{thrived}  => q{past 'thriving' --> 'thrived'};
is verb(q{flown})->past, q{flew}  => q{past 'flown' --> 'flew'};
is verb(q{treads})->past, q{trod}  => q{past 'treads' --> 'trod'};
is verb(q{continuing})->past, q{continued}  => q{past 'continuing' --> 'continued'};
is verb(q{bust})->past, q{bust}  => q{past 'bust' --> 'bust'};
is verb(q{been})->past, q{was}  => q{past 'been' --> 'was'};
is verb(q{ridden})->past, q{rode}  => q{past 'ridden' --> 'rode'};
is verb(q{beaten})->past, q{beat}  => q{past 'beaten' --> 'beat'};
is verb(q{happens})->past, q{happened}  => q{past 'happens' --> 'happened'};
is verb(q{bind})->past, q{bound}  => q{past 'bind' --> 'bound'};
is verb(q{quizzes})->past, q{quizzed}  => q{past 'quizzes' --> 'quizzed'};
is verb(q{misled})->past, q{misled}  => q{past 'misled' --> 'misled'};
is verb(q{meaning})->past, q{meant}  => q{past 'meaning' --> 'meant'};
is verb(q{becoming})->past, q{became}  => q{past 'becoming' --> 'became'};
is verb(q{shaking})->past, q{shook}  => q{past 'shaking' --> 'shook'};
is verb(q{shan't})->past, q{shouldn't}  => q{past 'shan't' --> 'shouldn't'};
is verb(q{dwells})->past, q{dwelt}  => q{past 'dwells' --> 'dwelt'};
is verb(q{withstanding})->past, q{withstood}  => q{past 'withstanding' --> 'withstood'};
is verb(q{swelling})->past, q{swelled}  => q{past 'swelling' --> 'swelled'};
is verb(q{behold})->past, q{beheld}  => q{past 'behold' --> 'beheld'};
is verb(q{clap})->past, q{clapped}  => q{past 'clap' --> 'clapped'};
is verb(q{sowing})->past, q{sowed}  => q{past 'sowing' --> 'sowed'};
is verb(q{hews})->past, q{hewed}  => q{past 'hews' --> 'hewed'};
is verb(q{shod})->past, q{shod}  => q{past 'shod' --> 'shod'};
is verb(q{springs})->past, q{sprang}  => q{past 'springs' --> 'sprang'};
is verb(q{shaving})->past, q{shaved}  => q{past 'shaving' --> 'shaved'};
is verb(q{leave})->past, q{left}  => q{past 'leave' --> 'left'};
is verb(q{prove})->past, q{proved}  => q{past 'prove' --> 'proved'};
is verb(q{overtaken})->past, q{overtook}  => q{past 'overtaken' --> 'overtook'};
is verb(q{seemed})->past, q{seemed}  => q{past 'seemed' --> 'seemed'};
is verb(q{weep})->past, q{wept}  => q{past 'weep' --> 'wept'};
is verb(q{overheard})->past, q{overheard}  => q{past 'overheard' --> 'overheard'};
is verb(q{quits})->past, q{quit}  => q{past 'quits' --> 'quit'};
is verb(q{deals})->past, q{dealt}  => q{past 'deals' --> 'dealt'};
is verb(q{follow})->past, q{followed}  => q{past 'follow' --> 'followed'};
is verb(q{niched})->past, q{niched}  => q{past 'niched' --> 'niched'};
is verb(q{menuing})->past, q{menued}  => q{past 'menuing' --> 'menued'};
is verb(q{flings})->past, q{flung}  => q{past 'flings' --> 'flung'};
is verb(q{mayn't})->past, q{mightn't}  => q{past 'mayn't' --> 'mightn't'};
is verb(q{sow})->past, q{sowed}  => q{past 'sow' --> 'sowed'};
is verb(q{caught})->past, q{caught}  => q{past 'caught' --> 'caught'};
is verb(q{look})->past, q{looked}  => q{past 'look' --> 'looked'};
is verb(q{rids})->past, q{rid}  => q{past 'rids' --> 'rid'};
is verb(q{killed})->past, q{killed}  => q{past 'killed' --> 'killed'};
is verb(q{thrived})->past, q{thrived}  => q{past 'thrived' --> 'thrived'};
is verb(q{clapping})->past, q{clapped}  => q{past 'clapping' --> 'clapped'};
is verb(q{followed})->past, q{followed}  => q{past 'followed' --> 'followed'};
is verb(q{foresees})->past, q{foresaw}  => q{past 'foresees' --> 'foresaw'};
is verb(q{knit})->past, q{knitted}  => q{past 'knit' --> 'knitted'};
is verb(q{sat})->past, q{sat}  => q{past 'sat' --> 'sat'};
is verb(q{wended})->past, q{wended}  => q{past 'wended' --> 'wended'};
is verb(q{coming})->past, q{came}  => q{past 'coming' --> 'came'};
is verb(q{foretold})->past, q{foretold}  => q{past 'foretold' --> 'foretold'};
is verb(q{dealing})->past, q{dealt}  => q{past 'dealing' --> 'dealt'};
is verb(q{sawing})->past, q{sawed}  => q{past 'sawing' --> 'sawed'};
is verb(q{show})->past, q{showed}  => q{past 'show' --> 'showed'};
is verb(q{can't})->past, q{couldn't}  => q{past 'can't' --> 'couldn't'};
is verb(q{dragging})->past, q{dragged}  => q{past 'dragging' --> 'dragged'};
is verb(q{avalanched})->past, q{avalanched}  => q{past 'avalanched' --> 'avalanched'};
is verb(q{lean})->past, q{leaned}  => q{past 'lean' --> 'leaned'};
is verb(q{menus})->past, q{menued}  => q{past 'menus' --> 'menued'};
is verb(q{irised})->past, q{irised}  => q{past 'irised' --> 'irised'};
is verb(q{slinks})->past, q{slunk}  => q{past 'slinks' --> 'slunk'};
is verb(q{awakening})->past, q{awoke}  => q{past 'awakening' --> 'awoke'};
is verb(q{knitted})->past, q{knitted}  => q{past 'knitted' --> 'knitted'};
is verb(q{wept})->past, q{wept}  => q{past 'wept' --> 'wept'};
is verb(q{slay})->past, q{slew}  => q{past 'slay' --> 'slew'};
is verb(q{slid})->past, q{slid}  => q{past 'slid' --> 'slid'};
is verb(q{aching})->past, q{ached}  => q{past 'aching' --> 'ached'};
is verb(q{hold})->past, q{held}  => q{past 'hold' --> 'held'};
is verb(q{fly})->past, q{flew}  => q{past 'fly' --> 'flew'};
is verb(q{follows})->past, q{followed}  => q{past 'follows' --> 'followed'};
is verb(q{sheds})->past, q{shed}  => q{past 'sheds' --> 'shed'};
is verb(q{walks})->past, q{walked}  => q{past 'walks' --> 'walked'};
is verb(q{eats})->past, q{ate}  => q{past 'eats' --> 'ate'};
is verb(q{forbidden})->past, q{forbade}  => q{past 'forbidden' --> 'forbade'};
is verb(q{stand})->past, q{stood}  => q{past 'stand' --> 'stood'};
is verb(q{niches})->past, q{niched}  => q{past 'niches' --> 'niched'};
is verb(q{drink})->past, q{drank}  => q{past 'drink' --> 'drank'};
is verb(q{clung})->past, q{clung}  => q{past 'clung' --> 'clung'};
is verb(q{misunderstanding})->past, q{misunderstood}  => q{past 'misunderstanding' --> 'misunderstood'};
is verb(q{stops})->past, q{stopped}  => q{past 'stops' --> 'stopped'};
is verb(q{breaking})->past, q{broke}  => q{past 'breaking' --> 'broke'};
is verb(q{catch})->past, q{caught}  => q{past 'catch' --> 'caught'};
is verb(q{waited})->past, q{waited}  => q{past 'waited' --> 'waited'};
is verb(q{slain})->past, q{slew}  => q{past 'slain' --> 'slew'};
is verb(q{sing})->past, q{sang}  => q{past 'sing' --> 'sang'};
is verb(q{swing})->past, q{swung}  => q{past 'swing' --> 'swung'};
is verb(q{love})->past, q{loved}  => q{past 'love' --> 'loved'};
is verb(q{goes})->past, q{went}  => q{past 'goes' --> 'went'};
is verb(q{keeps})->past, q{kept}  => q{past 'keeps' --> 'kept'};
is verb(q{walking})->past, q{walked}  => q{past 'walking' --> 'walked'};
is verb(q{betting})->past, q{bet}  => q{past 'betting' --> 'bet'};
is verb(q{remembered})->past, q{remembered}  => q{past 'remembered' --> 'remembered'};
is verb(q{douched})->past, q{douched}  => q{past 'douched' --> 'douched'};
is verb(q{swinging})->past, q{swung}  => q{past 'swinging' --> 'swung'};
is verb(q{gild})->past, q{gilded}  => q{past 'gild' --> 'gilded'};
is verb(q{were})->past, q{were}  => q{past 'were' --> 'were'};
is verb(q{learns})->past, q{learned}  => q{past 'learns' --> 'learned'};
is verb(q{irises})->past, q{irised}  => q{past 'irises' --> 'irised'};
is verb(q{stunk})->past, q{stank}  => q{past 'stunk' --> 'stank'};
is verb(q{lays})->past, q{laid}  => q{past 'lays' --> 'laid'};
is verb(q{catching})->past, q{caught}  => q{past 'catching' --> 'caught'};
is verb(q{swim})->past, q{swam}  => q{past 'swim' --> 'swam'};
is verb(q{overtakes})->past, q{overtook}  => q{past 'overtakes' --> 'overtook'};
is verb(q{drinking})->past, q{drank}  => q{past 'drinking' --> 'drank'};
is verb(q{bite})->past, q{bit}  => q{past 'bite' --> 'bit'};
is verb(q{liked})->past, q{liked}  => q{past 'liked' --> 'liked'};
is verb(q{bellyaching})->past, q{bellyached}  => q{past 'bellyaching' --> 'bellyached'};
is verb(q{going})->past, q{went}  => q{past 'going' --> 'went'};
is verb(q{continued})->past, q{continued}  => q{past 'continued' --> 'continued'};
is verb(q{foretells})->past, q{foretold}  => q{past 'foretells' --> 'foretold'};
is verb(q{break})->past, q{broke}  => q{past 'break' --> 'broke'};
is verb(q{helped})->past, q{helped}  => q{past 'helped' --> 'helped'};
is verb(q{begin})->past, q{began}  => q{past 'begin' --> 'began'};
is verb(q{stripped})->past, q{stripped}  => q{past 'stripped' --> 'stripped'};
is verb(q{standing})->past, q{stood}  => q{past 'standing' --> 'stood'};
is verb(q{moved})->past, q{moved}  => q{past 'moved' --> 'moved'};
is verb(q{keeping})->past, q{kept}  => q{past 'keeping' --> 'kept'};
is verb(q{watching})->past, q{watched}  => q{past 'watching' --> 'watched'};
is verb(q{creeps})->past, q{crept}  => q{past 'creeps' --> 'crept'};
is verb(q{staying})->past, q{stayed}  => q{past 'staying' --> 'stayed'};
is verb(q{spoiling})->past, q{spoilt}  => q{past 'spoiling' --> 'spoilt'};
is verb(q{thrive})->past, q{thrived}  => q{past 'thrive' --> 'thrived'};
is verb(q{spends})->past, q{spent}  => q{past 'spends' --> 'spent'};
is verb(q{building})->past, q{built}  => q{past 'building' --> 'built'};
is verb(q{bleeds})->past, q{bled}  => q{past 'bleeds' --> 'bled'};
is verb(q{douches})->past, q{douched}  => q{past 'douches' --> 'douched'};
is verb(q{stinging})->past, q{stung}  => q{past 'stinging' --> 'stung'};
is verb(q{wear})->past, q{wore}  => q{past 'wear' --> 'wore'};
is verb(q{forgetting})->past, q{forgot}  => q{past 'forgetting' --> 'forgot'};
is verb(q{flee})->past, q{fled}  => q{past 'flee' --> 'fled'};
is verb(q{bellyache})->past, q{bellyached}  => q{past 'bellyache' --> 'bellyached'};
is verb(q{can})->past, q{could}  => q{past 'can' --> 'could'};
is verb(q{forgets})->past, q{forgot}  => q{past 'forgets' --> 'forgot'};
is verb(q{sink})->past, q{sank}  => q{past 'sink' --> 'sank'};
is verb(q{hurting})->past, q{hurt}  => q{past 'hurting' --> 'hurt'};
is verb(q{withstood})->past, q{withstood}  => q{past 'withstood' --> 'withstood'};
is verb(q{talked})->past, q{talked}  => q{past 'talked' --> 'talked'};
is verb(q{mistaken})->past, q{mistook}  => q{past 'mistaken' --> 'mistook'};
is verb(q{rid})->past, q{rid}  => q{past 'rid' --> 'rid'};
is verb(q{spat})->past, q{spat}  => q{past 'spat' --> 'spat'};
is verb(q{spits})->past, q{spat}  => q{past 'spits' --> 'spat'};
is verb(q{spoken})->past, q{spoke}  => q{past 'spoken' --> 'spoke'};
is verb(q{stays})->past, q{stayed}  => q{past 'stays' --> 'stayed'};
is verb(q{hewing})->past, q{hewed}  => q{past 'hewing' --> 'hewed'};
is verb(q{stripping})->past, q{stripped}  => q{past 'stripping' --> 'stripped'};
is verb(q{sows})->past, q{sowed}  => q{past 'sows' --> 'sowed'};
is verb(q{inlaid})->past, q{inlaid}  => q{past 'inlaid' --> 'inlaid'};
is verb(q{become})->past, q{became}  => q{past 'become' --> 'became'};
is verb(q{blow})->past, q{blew}  => q{past 'blow' --> 'blew'};
is verb(q{sting})->past, q{stung}  => q{past 'sting' --> 'stung'};
is verb(q{build})->past, q{built}  => q{past 'build' --> 'built'};
is verb(q{led})->past, q{led}  => q{past 'led' --> 'led'};
is verb(q{caches})->past, q{cached}  => q{past 'caches' --> 'cached'};
is verb(q{hurts})->past, q{hurt}  => q{past 'hurts' --> 'hurt'};
is verb(q{watch})->past, q{watched}  => q{past 'watch' --> 'watched'};
is verb(q{brings})->past, q{brought}  => q{past 'brings' --> 'brought'};
is verb(q{withdraws})->past, q{withdrew}  => q{past 'withdraws' --> 'withdrew'};
is verb(q{preset})->past, q{preset}  => q{past 'preset' --> 'preset'};
is verb(q{spoil})->past, q{spoilt}  => q{past 'spoil' --> 'spoilt'};
is verb(q{dwelt})->past, q{dwelt}  => q{past 'dwelt' --> 'dwelt'};
is verb(q{understanding})->past, q{understood}  => q{past 'understanding' --> 'understood'};
is verb(q{douche})->past, q{douched}  => q{past 'douche' --> 'douched'};
is verb(q{rung})->past, q{rang}  => q{past 'rung' --> 'rang'};
is verb(q{stealing})->past, q{stole}  => q{past 'stealing' --> 'stole'};
is verb(q{thrives})->past, q{thrived}  => q{past 'thrives' --> 'thrived'};
is verb(q{withdrawn})->past, q{withdrew}  => q{past 'withdrawn' --> 'withdrew'};
is verb(q{burning})->past, q{burnt}  => q{past 'burning' --> 'burnt'};
is verb(q{needs})->past, q{needed}  => q{past 'needs' --> 'needed'};
is verb(q{inlay})->past, q{inlaid}  => q{past 'inlay' --> 'inlaid'};
is verb(q{digging})->past, q{dug}  => q{past 'digging' --> 'dug'};
is verb(q{breeds})->past, q{bred}  => q{past 'breeds' --> 'bred'};
is verb(q{swept})->past, q{swept}  => q{past 'swept' --> 'swept'};
is verb(q{overdraw})->past, q{overdrew}  => q{past 'overdraw' --> 'overdrew'};
is verb(q{lay})->past, q{laid}  => q{past 'lay' --> 'laid'};
is verb(q{overdrawing})->past, q{overdrew}  => q{past 'overdrawing' --> 'overdrew'};
is verb(q{dare})->past, q{dared}  => q{past 'dare' --> 'dared'};
is verb(q{kneeling})->past, q{knelt}  => q{past 'kneeling' --> 'knelt'};
is verb(q{psyching})->past, q{psyched}  => q{past 'psyching' --> 'psyched'};
is verb(q{interlays})->past, q{interlaid}  => q{past 'interlays' --> 'interlaid'};
is verb(q{forget})->past, q{forgot}  => q{past 'forget' --> 'forgot'};
is verb(q{lived})->past, q{lived}  => q{past 'lived' --> 'lived'};
is verb(q{quiz})->past, q{quizzed}  => q{past 'quiz' --> 'quizzed'};
is verb(q{foresee})->past, q{foresaw}  => q{past 'foresee' --> 'foresaw'};
is verb(q{rise})->past, q{rose}  => q{past 'rise' --> 'rose'};
is verb(q{aches})->past, q{ached}  => q{past 'aches' --> 'ached'};
is verb(q{grinds})->past, q{ground}  => q{past 'grinds' --> 'ground'};
is verb(q{riven})->past, q{rived}  => q{past 'riven' --> 'rived'};
is verb(q{wrung})->past, q{wrung}  => q{past 'wrung' --> 'wrung'};
is verb(q{becomes})->past, q{became}  => q{past 'becomes' --> 'became'};
is verb(q{undergoes})->past, q{underwent}  => q{past 'undergoes' --> 'underwent'};
is verb(q{cached})->past, q{cached}  => q{past 'cached' --> 'cached'};
is verb(q{interlaid})->past, q{interlaid}  => q{past 'interlaid' --> 'interlaid'};
is verb(q{burns})->past, q{burnt}  => q{past 'burns' --> 'burnt'};
is verb(q{needing})->past, q{needed}  => q{past 'needing' --> 'needed'};
is verb(q{presetting})->past, q{preset}  => q{past 'presetting' --> 'preset'};
is verb(q{arises})->past, q{arose}  => q{past 'arises' --> 'arose'};
is verb(q{dug})->past, q{dug}  => q{past 'dug' --> 'dug'};
is verb(q{kneel})->past, q{knelt}  => q{past 'kneel' --> 'knelt'};
is verb(q{sunburned})->past, q{sunburned}  => q{past 'sunburned' --> 'sunburned'};
is verb(q{following})->past, q{followed}  => q{past 'following' --> 'followed'};
is verb(q{comes})->past, q{came}  => q{past 'comes' --> 'came'};
is verb(q{sprung})->past, q{sprang}  => q{past 'sprung' --> 'sprang'};
is verb(q{quizzing})->past, q{quizzed}  => q{past 'quizzing' --> 'quizzed'};
is verb(q{strewn})->past, q{strewed}  => q{past 'strewn' --> 'strewed'};
is verb(q{worn})->past, q{wore}  => q{past 'worn' --> 'wore'};
is verb(q{presets})->past, q{preset}  => q{past 'presets' --> 'preset'};
is verb(q{foreseeing})->past, q{foresaw}  => q{past 'foreseeing' --> 'foresaw'};
is verb(q{bitten})->past, q{bit}  => q{past 'bitten' --> 'bit'};
is verb(q{inlaying})->past, q{inlaid}  => q{past 'inlaying' --> 'inlaid'};
is verb(q{given})->past, q{gave}  => q{past 'given' --> 'gave'};
is verb(q{eat})->past, q{ate}  => q{past 'eat' --> 'ate'};
is verb(q{swimming})->past, q{swam}  => q{past 'swimming' --> 'swam'};
is verb(q{slits})->past, q{slit}  => q{past 'slits' --> 'slit'};
is verb(q{steal})->past, q{stole}  => q{past 'steal' --> 'stole'};
is verb(q{have})->past, q{had}  => q{past 'have' --> 'had'};
is verb(q{vexes})->past, q{vexed}  => q{past 'vexes' --> 'vexed'};
is verb(q{sown})->past, q{sowed}  => q{past 'sown' --> 'sowed'};
is verb(q{sinking})->past, q{sank}  => q{past 'sinking' --> 'sank'};
is verb(q{shrunk})->past, q{shrank}  => q{past 'shrunk' --> 'shrank'};
is verb(q{felt})->past, q{felt}  => q{past 'felt' --> 'felt'};
is verb(q{fleeing})->past, q{fled}  => q{past 'fleeing' --> 'fled'};
is verb(q{forbid})->past, q{forbade}  => q{past 'forbid' --> 'forbade'};
is verb(q{put})->past, q{put}  => q{past 'put' --> 'put'};
is verb(q{forsake})->past, q{forsook}  => q{past 'forsake' --> 'forsook'};
is verb(q{creching})->past, q{creched}  => q{past 'creching' --> 'creched'};
is verb(q{drives})->past, q{drove}  => q{past 'drives' --> 'drove'};
is verb(q{hurt})->past, q{hurt}  => q{past 'hurt' --> 'hurt'};
is verb(q{gone})->past, q{went}  => q{past 'gone' --> 'went'};
is verb(q{sit})->past, q{sat}  => q{past 'sit' --> 'sat'};
is verb(q{built})->past, q{built}  => q{past 'built' --> 'built'};
is verb(q{stay})->past, q{stayed}  => q{past 'stay' --> 'stayed'};
is verb(q{stinks})->past, q{stank}  => q{past 'stinks' --> 'stank'};
is verb(q{wearing})->past, q{wore}  => q{past 'wearing' --> 'wore'};
is verb(q{biting})->past, q{bit}  => q{past 'biting' --> 'bit'};
is verb(q{sworn})->past, q{swore}  => q{past 'sworn' --> 'swore'};
is verb(q{blows})->past, q{blew}  => q{past 'blows' --> 'blew'};
is verb(q{abiding})->past, q{abided}  => q{past 'abiding' --> 'abided'};
is verb(q{sinks})->past, q{sank}  => q{past 'sinks' --> 'sank'};
is verb(q{striving})->past, q{strove}  => q{past 'striving' --> 'strove'};
is verb(q{flees})->past, q{fled}  => q{past 'flees' --> 'fled'};
is verb(q{avalanching})->past, q{avalanched}  => q{past 'avalanching' --> 'avalanched'};
is verb(q{bred})->past, q{bred}  => q{past 'bred' --> 'bred'};
is verb(q{spit})->past, q{spat}  => q{past 'spit' --> 'spat'};
is verb(q{leapt})->past, q{leapt}  => q{past 'leapt' --> 'leapt'};
is verb(q{loving})->past, q{loved}  => q{past 'loving' --> 'loved'};
is verb(q{speaks})->past, q{spoke}  => q{past 'speaks' --> 'spoke'};
is verb(q{forgives})->past, q{forgave}  => q{past 'forgives' --> 'forgave'};
is verb(q{learned})->past, q{learned}  => q{past 'learned' --> 'learned'};
is verb(q{shaves})->past, q{shaved}  => q{past 'shaves' --> 'shaved'};
is verb(q{insisting})->past, q{insisted}  => q{past 'insisting' --> 'insisted'};
is verb(q{wears})->past, q{wore}  => q{past 'wears' --> 'wore'};
is verb(q{expects})->past, q{expected}  => q{past 'expects' --> 'expected'};
is verb(q{shakes})->past, q{shook}  => q{past 'shakes' --> 'shook'};
is verb(q{proved})->past, q{proved}  => q{past 'proved' --> 'proved'};
is verb(q{clings})->past, q{clung}  => q{past 'clings' --> 'clung'};
is verb(q{go})->past, q{went}  => q{past 'go' --> 'went'};
is verb(q{blowing})->past, q{blew}  => q{past 'blowing' --> 'blew'};
is verb(q{ask})->past, q{asked}  => q{past 'ask' --> 'asked'};
is verb(q{come})->past, q{came}  => q{past 'come' --> 'came'};
is verb(q{abide})->past, q{abided}  => q{past 'abide' --> 'abided'};
is verb(q{forbids})->past, q{forbade}  => q{past 'forbids' --> 'forbade'};
is verb(q{isn't})->past, q{wasn't}  => q{past 'isn't' --> 'wasn't'};
is verb(q{sha'n't})->past, q{shouldn't}  => q{past 'sha'n't' --> 'shouldn't'};
is verb(q{slunk})->past, q{slunk}  => q{past 'slunk' --> 'slunk'};
is verb(q{changing})->past, q{changed}  => q{past 'changing' --> 'changed'};
is verb(q{slit})->past, q{slit}  => q{past 'slit' --> 'slit'};
is verb(q{lain})->past, q{lay}  => q{past 'lain' --> 'lay'};
is verb(q{dived})->past, q{dived}  => q{past 'dived' --> 'dived'};
is verb(q{withholds})->past, q{withheld}  => q{past 'withholds' --> 'withheld'};
is verb(q{tread})->past, q{trod}  => q{past 'tread' --> 'trod'};
is verb(q{undergoing})->past, q{underwent}  => q{past 'undergoing' --> 'underwent'};
is verb(q{forsaking})->past, q{forsook}  => q{past 'forsaking' --> 'forsook'};
is verb(q{expected})->past, q{expected}  => q{past 'expected' --> 'expected'};
is verb(q{swells})->past, q{swelled}  => q{past 'swells' --> 'swelled'};
is verb(q{ache})->past, q{ached}  => q{past 'ache' --> 'ached'};
is verb(q{rises})->past, q{rose}  => q{past 'rises' --> 'rose'};
is verb(q{hit})->past, q{hit}  => q{past 'hit' --> 'hit'};
is verb(q{swollen})->past, q{swelled}  => q{past 'swollen' --> 'swelled'};
is verb(q{burn})->past, q{burnt}  => q{past 'burn' --> 'burnt'};
is verb(q{win})->past, q{won}  => q{past 'win' --> 'won'};
is verb(q{dwelling})->past, q{dwelt}  => q{past 'dwelling' --> 'dwelt'};
is verb(q{bellyached})->past, q{bellyached}  => q{past 'bellyached' --> 'bellyached'};
is verb(q{reached})->past, q{reached}  => q{past 'reached' --> 'reached'};
is verb(q{dares})->past, q{dared}  => q{past 'dares' --> 'dared'};
is verb(q{dwell})->past, q{dwelt}  => q{past 'dwell' --> 'dwelt'};
is verb(q{shaved})->past, q{shaved}  => q{past 'shaved' --> 'shaved'};
is verb(q{misunderstand})->past, q{misunderstood}  => q{past 'misunderstand' --> 'misunderstood'};
is verb(q{undertaking})->past, q{undertook}  => q{past 'undertaking' --> 'undertook'};
is verb(q{blitzed})->past, q{blitzed}  => q{past 'blitzed' --> 'blitzed'};
is verb(q{flung})->past, q{flung}  => q{past 'flung' --> 'flung'};
is verb(q{bled})->past, q{bled}  => q{past 'bled' --> 'bled'};
is verb(q{proves})->past, q{proved}  => q{past 'proves' --> 'proved'};
is verb(q{leaves})->past, q{left}  => q{past 'leaves' --> 'left'};
is verb(q{begetting})->past, q{begot}  => q{past 'begetting' --> 'begot'};
is verb(q{remember})->past, q{remembered}  => q{past 'remember' --> 'remembered'};
is verb(q{remembering})->past, q{remembered}  => q{past 'remembering' --> 'remembered'};
is verb(q{treading})->past, q{trod}  => q{past 'treading' --> 'trod'};
is verb(q{expect})->past, q{expected}  => q{past 'expect' --> 'expected'};
is verb(q{undergo})->past, q{underwent}  => q{past 'undergo' --> 'underwent'};
is verb(q{getting})->past, q{got}  => q{past 'getting' --> 'got'};
is verb(q{remaining})->past, q{remained}  => q{past 'remaining' --> 'remained'};
is verb(q{need})->past, q{needed}  => q{past 'need' --> 'needed'};
is verb(q{forbidding})->past, q{forbade}  => q{past 'forbidding' --> 'forbade'};
is verb(q{leans})->past, q{leaned}  => q{past 'leans' --> 'leaned'};
is verb(q{remain})->past, q{remained}  => q{past 'remain' --> 'remained'};
is verb(q{menu})->past, q{menued}  => q{past 'menu' --> 'menued'};
is verb(q{blitzes})->past, q{blitzed}  => q{past 'blitzes' --> 'blitzed'};
is verb(q{shows})->past, q{showed}  => q{past 'shows' --> 'showed'};
is verb(q{insists})->past, q{insisted}  => q{past 'insists' --> 'insisted'};
is verb(q{undertake})->past, q{undertook}  => q{past 'undertake' --> 'undertook'};
is verb(q{holds})->past, q{held}  => q{past 'holds' --> 'held'};
is verb(q{expecting})->past, q{expected}  => q{past 'expecting' --> 'expected'};
is verb(q{strides})->past, q{strode}  => q{past 'strides' --> 'strode'};
is verb(q{swearing})->past, q{swore}  => q{past 'swearing' --> 'swore'};
is verb(q{speed})->past, q{sped}  => q{past 'speed' --> 'sped'};
is verb(q{fled})->past, q{fled}  => q{past 'fled' --> 'fled'};
is verb(q{reaches})->past, q{reached}  => q{past 'reaches' --> 'reached'};
is verb(q{rising})->past, q{rose}  => q{past 'rising' --> 'rose'};
is verb(q{slays})->past, q{slew}  => q{past 'slays' --> 'slew'};
is verb(q{sneak})->past, q{sneaked}  => q{past 'sneak' --> 'sneaked'};
is verb(q{having})->past, q{had}  => q{past 'having' --> 'had'};
is verb(q{weeping})->past, q{wept}  => q{past 'weeping' --> 'wept'};
is verb(q{dream})->past, q{dreamed}  => q{past 'dream' --> 'dreamed'};
is verb(q{smelling})->past, q{smelled}  => q{past 'smelling' --> 'smelled'};
is verb(q{wanted})->past, q{wanted}  => q{past 'wanted' --> 'wanted'};
is verb(q{looks})->past, q{looked}  => q{past 'looks' --> 'looked'};
is verb(q{wrings})->past, q{wrung}  => q{past 'wrings' --> 'wrung'};
is verb(q{upset})->past, q{upset}  => q{past 'upset' --> 'upset'};
is verb(q{withstands})->past, q{withstood}  => q{past 'withstands' --> 'withstood'};
is verb(q{met})->past, q{met}  => q{past 'met' --> 'met'};
is verb(q{sweeping})->past, q{swept}  => q{past 'sweeping' --> 'swept'};
is verb(q{knits})->past, q{knitted}  => q{past 'knits' --> 'knitted'};
is verb(q{forgiving})->past, q{forgave}  => q{past 'forgiving' --> 'forgave'};
is verb(q{skiing})->past, q{skied}  => q{past 'skiing' --> 'skied'};
is verb(q{leaning})->past, q{leaned}  => q{past 'leaning' --> 'leaned'};
is verb(q{beginning})->past, q{began}  => q{past 'beginning' --> 'began'};
is verb(q{smitten})->past, q{smote}  => q{past 'smitten' --> 'smote'};
is verb(q{remained})->past, q{remained}  => q{past 'remained' --> 'remained'};
is verb(q{asked})->past, q{asked}  => q{past 'asked' --> 'asked'};
is verb(q{sweep})->past, q{swept}  => q{past 'sweep' --> 'swept'};
is verb(q{showing})->past, q{showed}  => q{past 'showing' --> 'showed'};
is verb(q{dreaming})->past, q{dreamed}  => q{past 'dreaming' --> 'dreamed'};
is verb(q{holding})->past, q{held}  => q{past 'holding' --> 'held'};
is verb(q{smell})->past, q{smelled}  => q{past 'smell' --> 'smelled'};
is verb(q{sneaking})->past, q{sneaked}  => q{past 'sneaking' --> 'sneaked'};
is verb(q{meant})->past, q{meant}  => q{past 'meant' --> 'meant'};
is verb(q{known})->past, q{knew}  => q{past 'known' --> 'knew'};
is verb(q{left})->past, q{left}  => q{past 'left' --> 'left'};
is verb(q{understood})->past, q{understood}  => q{past 'understood' --> 'understood'};
is verb(q{are})->past, q{were}  => q{past 'are' --> 'were'};
is verb(q{slaying})->past, q{slew}  => q{past 'slaying' --> 'slew'};
is verb(q{sliding})->past, q{slid}  => q{past 'sliding' --> 'slid'};
is verb(q{weeps})->past, q{wept}  => q{past 'weeps' --> 'wept'};
is verb(q{speeding})->past, q{sped}  => q{past 'speeding' --> 'sped'};
is verb(q{sits})->past, q{sat}  => q{past 'sits' --> 'sat'};
is verb(q{swear})->past, q{swore}  => q{past 'swear' --> 'swore'};
is verb(q{looking})->past, q{looked}  => q{past 'looking' --> 'looked'};
is verb(q{puts})->past, q{put}  => q{past 'puts' --> 'put'};
is verb(q{strips})->past, q{stripped}  => q{past 'strips' --> 'stripped'};
is verb(q{daring})->past, q{dared}  => q{past 'daring' --> 'dared'};
is verb(q{staving})->past, q{staved}  => q{past 'staving' --> 'staved'};
is verb(q{deal})->past, q{dealt}  => q{past 'deal' --> 'dealt'};
is verb(q{continue})->past, q{continued}  => q{past 'continue' --> 'continued'};
is verb(q{smites})->past, q{smote}  => q{past 'smites' --> 'smote'};
is verb(q{bursts})->past, q{burst}  => q{past 'bursts' --> 'burst'};
is verb(q{quit})->past, q{quit}  => q{past 'quit' --> 'quit'};
is verb(q{bites})->past, q{bit}  => q{past 'bites' --> 'bit'};
is verb(q{overtaking})->past, q{overtook}  => q{past 'overtaking' --> 'overtook'};
is verb(q{stride})->past, q{strode}  => q{past 'stride' --> 'strode'};
is verb(q{avalanche})->past, q{avalanched}  => q{past 'avalanche' --> 'avalanched'};
is verb(q{forgive})->past, q{forgave}  => q{past 'forgive' --> 'forgave'};
is verb(q{insist})->past, q{insisted}  => q{past 'insist' --> 'insisted'};
is verb(q{singing})->past, q{sang}  => q{past 'singing' --> 'sang'};
is verb(q{sweat})->past, q{sweat}  => q{past 'sweat' --> 'sweat'};
is verb(q{shitting})->past, q{shat}  => q{past 'shitting' --> 'shat'};
is verb(q{overhearing})->past, q{overheard}  => q{past 'overhearing' --> 'overheard'};
is verb(q{remains})->past, q{remained}  => q{past 'remains' --> 'remained'};
is verb(q{fights})->past, q{fought}  => q{past 'fights' --> 'fought'};
is verb(q{overhear})->past, q{overheard}  => q{past 'overhear' --> 'overheard'};
is verb(q{died})->past, q{died}  => q{past 'died' --> 'died'};
is verb(q{gilds})->past, q{gilded}  => q{past 'gilds' --> 'gilded'};
is verb(q{strew})->past, q{strewed}  => q{past 'strew' --> 'strewed'};
is verb(q{kept})->past, q{kept}  => q{past 'kept' --> 'kept'};
is verb(q{winning})->past, q{won}  => q{past 'winning' --> 'won'};
is verb(q{vexing})->past, q{vexed}  => q{past 'vexing' --> 'vexed'};
is verb(q{stopped})->past, q{stopped}  => q{past 'stopped' --> 'stopped'};
is verb(q{swims})->past, q{swam}  => q{past 'swims' --> 'swam'};
is verb(q{awoken})->past, q{awoke}  => q{past 'awoken' --> 'awoke'};
is verb(q{sought})->past, q{sought}  => q{past 'sought' --> 'sought'};
is verb(q{insisted})->past, q{insisted}  => q{past 'insisted' --> 'insisted'};
is verb(q{stave})->past, q{staved}  => q{past 'stave' --> 'staved'};
is verb(q{has})->past, q{had}  => q{past 'has' --> 'had'};
is verb(q{awake})->past, q{awoke}  => q{past 'awake' --> 'awoke'};
is verb(q{wins})->past, q{won}  => q{past 'wins' --> 'won'};
is verb(q{eaten})->past, q{ate}  => q{past 'eaten' --> 'ate'};
is verb(q{sings})->past, q{sang}  => q{past 'sings' --> 'sang'};
is verb(q{keep})->past, q{kept}  => q{past 'keep' --> 'kept'};
is verb(q{loves})->past, q{loved}  => q{past 'loves' --> 'loved'};
is verb(q{hits})->past, q{hit}  => q{past 'hits' --> 'hit'};
is verb(q{strewing})->past, q{strewed}  => q{past 'strewing' --> 'strewed'};
is verb(q{choosing})->past, q{chose}  => q{past 'choosing' --> 'chose'};
is verb(q{sweating})->past, q{sweat}  => q{past 'sweating' --> 'sweat'};
is verb(q{gilding})->past, q{gilded}  => q{past 'gilding' --> 'gilded'};
is verb(q{begets})->past, q{begot}  => q{past 'begets' --> 'begot'};
is verb(q{walk})->past, q{walked}  => q{past 'walk' --> 'walked'};
is verb(q{shed})->past, q{shed}  => q{past 'shed' --> 'shed'};
is verb(q{slide})->past, q{slid}  => q{past 'slide' --> 'slid'};
is verb(q{forsakes})->past, q{forsook}  => q{past 'forsakes' --> 'forsook'};
is verb(q{asks})->past, q{asked}  => q{past 'asks' --> 'asked'};
is verb(q{stop})->past, q{stopped}  => q{past 'stop' --> 'stopped'};
is verb(q{understands})->past, q{understood}  => q{past 'understands' --> 'understood'};
is verb(q{talking})->past, q{talked}  => q{past 'talking' --> 'talked'};
is verb(q{giving})->past, q{gave}  => q{past 'giving' --> 'gave'};
is verb(q{get})->past, q{got}  => q{past 'get' --> 'got'};
is verb(q{shrinks})->past, q{shrank}  => q{past 'shrinks' --> 'shrank'};
is verb(q{bend})->past, q{bent}  => q{past 'bend' --> 'bent'};
is verb(q{sweated})->past, q{sweat}  => q{past 'sweated' --> 'sweat'};
is verb(q{chosen})->past, q{chose}  => q{past 'chosen' --> 'chose'};
is verb(q{misleads})->past, q{misled}  => q{past 'misleads' --> 'misled'};
is verb(q{move})->past, q{moved}  => q{past 'move' --> 'moved'};
is verb(q{ride})->past, q{rode}  => q{past 'ride' --> 'rode'};
is verb(q{bringing})->past, q{brought}  => q{past 'bringing' --> 'brought'};
is verb(q{change})->past, q{changed}  => q{past 'change' --> 'changed'};
is verb(q{creep})->past, q{crept}  => q{past 'creep' --> 'crept'};
is verb(q{bleed})->past, q{bled}  => q{past 'bleed' --> 'bled'};
is verb(q{stayed})->past, q{stayed}  => q{past 'stayed' --> 'stayed'};
is verb(q{seek})->past, q{sought}  => q{past 'seek' --> 'sought'};
is verb(q{spend})->past, q{spent}  => q{past 'spend' --> 'spent'};
is verb(q{creches})->past, q{creched}  => q{past 'creches' --> 'creched'};
is verb(q{riving})->past, q{rived}  => q{past 'riving' --> 'rived'};
is verb(q{like})->past, q{liked}  => q{past 'like' --> 'liked'};
is verb(q{stings})->past, q{stung}  => q{past 'stings' --> 'stung'};
is verb(q{stopping})->past, q{stopped}  => q{past 'stopping' --> 'stopped'};
is verb(q{bellyaches})->past, q{bellyached}  => q{past 'bellyaches' --> 'bellyached'};
is verb(q{bleeding})->past, q{bled}  => q{past 'bleeding' --> 'bled'};
is verb(q{builds})->past, q{built}  => q{past 'builds' --> 'built'};
is verb(q{shit})->past, q{shat}  => q{past 'shit' --> 'shat'};
is verb(q{arising})->past, q{arose}  => q{past 'arising' --> 'arose'};
is verb(q{spending})->past, q{spent}  => q{past 'spending' --> 'spent'};
is verb(q{talks})->past, q{talked}  => q{past 'talks' --> 'talked'};
is verb(q{hitting})->past, q{hit}  => q{past 'hitting' --> 'hit'};
is verb(q{overhears})->past, q{overheard}  => q{past 'overhears' --> 'overheard'};
is verb(q{cache})->past, q{cached}  => q{past 'cache' --> 'cached'};
is verb(q{strode})->past, q{strode}  => q{past 'strode' --> 'strode'};
is verb(q{thrust})->past, q{thrust}  => q{past 'thrust' --> 'thrust'};
is verb(q{creeping})->past, q{crept}  => q{past 'creeping' --> 'crept'};
is verb(q{fall})->past, q{fell}  => q{past 'fall' --> 'fell'};
is verb(q{bring})->past, q{brought}  => q{past 'bring' --> 'brought'};
is verb(q{provide})->past, q{provided}  => q{past 'provide' --> 'provided'};
is verb(q{spoils})->past, q{spoilt}  => q{past 'spoils' --> 'spoilt'};
is verb(q{strives})->past, q{strove}  => q{past 'strives' --> 'strove'};
is verb(q{shitted})->past, q{shat}  => q{past 'shitted' --> 'shat'};
is verb(q{loved})->past, q{loved}  => q{past 'loved' --> 'loved'};
is verb(q{sung})->past, q{sang}  => q{past 'sung' --> 'sang'};
is verb(q{vex})->past, q{vexed}  => q{past 'vex' --> 'vexed'};
is verb(q{know})->past, q{knew}  => q{past 'know' --> 'knew'};
is verb(q{digs})->past, q{dug}  => q{past 'digs' --> 'dug'};
is verb(q{withheld})->past, q{withheld}  => q{past 'withheld' --> 'withheld'};
is verb(q{die})->past, q{died}  => q{past 'die' --> 'died'};
is verb(q{shrink})->past, q{shrank}  => q{past 'shrink' --> 'shrank'};
is verb(q{diving})->past, q{dived}  => q{past 'diving' --> 'dived'};
is verb(q{claps})->past, q{clapped}  => q{past 'claps' --> 'clapped'};
is verb(q{grinding})->past, q{ground}  => q{past 'grinding' --> 'ground'};
is verb(q{creche})->past, q{creched}  => q{past 'creche' --> 'creched'};
is verb(q{sneaked})->past, q{sneaked}  => q{past 'sneaked' --> 'sneaked'};
is verb(q{dreamed})->past, q{dreamed}  => q{past 'dreamed' --> 'dreamed'};
is verb(q{binds})->past, q{bound}  => q{past 'binds' --> 'bound'};
is verb(q{busts})->past, q{bust}  => q{past 'busts' --> 'bust'};
is verb(q{continues})->past, q{continued}  => q{past 'continues' --> 'continued'};
is verb(q{quitting})->past, q{quit}  => q{past 'quitting' --> 'quit'};
is verb(q{breed})->past, q{bred}  => q{past 'breed' --> 'bred'};
is verb(q{changes})->past, q{changed}  => q{past 'changes' --> 'changed'};
is verb(q{hewn})->past, q{hewed}  => q{past 'hewn' --> 'hewed'};
is verb(q{inlays})->past, q{inlaid}  => q{past 'inlays' --> 'inlaid'};
is verb(q{mistakes})->past, q{mistook}  => q{past 'mistakes' --> 'mistook'};
is verb(q{breeding})->past, q{bred}  => q{past 'breeding' --> 'bred'};
is verb(q{thrusts})->past, q{thrust}  => q{past 'thrusts' --> 'thrust'};
is verb(q{smelled})->past, q{smelled}  => q{past 'smelled' --> 'smelled'};
is verb(q{being})->past, q{was}  => q{past 'being' --> 'was'};
is verb(q{dealt})->past, q{dealt}  => q{past 'dealt' --> 'dealt'};
is verb(q{ground})->past, q{ground}  => q{past 'ground' --> 'ground'};
is verb(q{steals})->past, q{stole}  => q{past 'steals' --> 'stole'};
is verb(q{grind})->past, q{ground}  => q{past 'grind' --> 'ground'};
is verb(q{needed})->past, q{needed}  => q{past 'needed' --> 'needed'};
is verb(q{binding})->past, q{bound}  => q{past 'binding' --> 'bound'};
is verb(q{busting})->past, q{bust}  => q{past 'busting' --> 'bust'};
is verb(q{providing})->past, q{provided}  => q{past 'providing' --> 'provided'};
is verb(q{mean})->past, q{meant}  => q{past 'mean' --> 'meant'};
is verb(q{arise})->past, q{arose}  => q{past 'arise' --> 'arose'};
is verb(q{stood})->past, q{stood}  => q{past 'stood' --> 'stood'};
is verb(q{loses})->past, q{lost}  => q{past 'loses' --> 'lost'};
is verb(q{putting})->past, q{put}  => q{past 'putting' --> 'put'};
is verb(q{rent})->past, q{rent}  => q{past 'rent' --> 'rent'};
is verb(q{shall})->past, q{should}  => q{past 'shall' --> 'should'};
is verb(q{kneels})->past, q{knelt}  => q{past 'kneels' --> 'knelt'};
is verb(q{ski})->past, q{skied}  => q{past 'ski' --> 'skied'};
is verb(q{sitting})->past, q{sat}  => q{past 'sitting' --> 'sat'};
is verb(q{strive})->past, q{strove}  => q{past 'strive' --> 'strove'};
is verb(q{caching})->past, q{cached}  => q{past 'caching' --> 'cached'};
is verb(q{dig})->past, q{dug}  => q{past 'dig' --> 'dug'};
is verb(q{sublet})->past, q{sublet}  => q{past 'sublet' --> 'sublet'};
is verb(q{fling})->past, q{flung}  => q{past 'fling' --> 'flung'};
is verb(q{feeling})->past, q{felt}  => q{past 'feeling' --> 'felt'};
is verb(q{burnt})->past, q{burnt}  => q{past 'burnt' --> 'burnt'};
is verb(q{woken})->past, q{woke}  => q{past 'woken' --> 'woke'};
is verb(q{shaken})->past, q{shook}  => q{past 'shaken' --> 'shook'};
is verb(q{menued})->past, q{menued}  => q{past 'menued' --> 'menued'};
is verb(q{torn})->past, q{tore}  => q{past 'torn' --> 'tore'};
is verb(q{drags})->past, q{dragged}  => q{past 'drags' --> 'dragged'};
is verb(q{meet})->past, q{met}  => q{past 'meet' --> 'met'};
is verb(q{slinking})->past, q{slunk}  => q{past 'slinking' --> 'slunk'};
is verb(q{blitzing})->past, q{blitzed}  => q{past 'blitzing' --> 'blitzed'};
is verb(q{trodden})->past, q{trod}  => q{past 'trodden' --> 'trod'};
is verb(q{dives})->past, q{dived}  => q{past 'dives' --> 'dived'};
is verb(q{mistake})->past, q{mistook}  => q{past 'mistake' --> 'mistook'};
is verb(q{wends})->past, q{wended}  => q{past 'wends' --> 'wended'};
is verb(q{finding})->past, q{found}  => q{past 'finding' --> 'found'};
is verb(q{reaching})->past, q{reached}  => q{past 'reaching' --> 'reached'};
is verb(q{seeming})->past, q{seemed}  => q{past 'seeming' --> 'seemed'};
is verb(q{remembers})->past, q{remembered}  => q{past 'remembers' --> 'remembered'};
is verb(q{skied})->past, q{skied}  => q{past 'skied' --> 'skied'};
is verb(q{striding})->past, q{strode}  => q{past 'striding' --> 'strode'};
is verb(q{ridding})->past, q{rid}  => q{past 'ridding' --> 'rid'};
is verb(q{kills})->past, q{killed}  => q{past 'kills' --> 'killed'};
is verb(q{rending})->past, q{rent}  => q{past 'rending' --> 'rent'};
is verb(q{want})->past, q{wanted}  => q{past 'want' --> 'wanted'};
is verb(q{may})->past, q{might}  => q{past 'may' --> 'might'};
is verb(q{beating})->past, q{beat}  => q{past 'beating' --> 'beat'};
is verb(q{reach})->past, q{reached}  => q{past 'reach' --> 'reached'};
is verb(q{withhold})->past, q{withheld}  => q{past 'withhold' --> 'withheld'};
is verb(q{losing})->past, q{lost}  => q{past 'losing' --> 'lost'};
is verb(q{slitting})->past, q{slit}  => q{past 'slitting' --> 'slit'};
is verb(q{cost})->past, q{cost}  => q{past 'cost' --> 'cost'};
is verb(q{withholding})->past, q{withheld}  => q{past 'withholding' --> 'withheld'};
is verb(q{asking})->past, q{asked}  => q{past 'asking' --> 'asked'};
is verb(q{slink})->past, q{slunk}  => q{past 'slink' --> 'slunk'};
is verb(q{blitz})->past, q{blitzed}  => q{past 'blitz' --> 'blitzed'};
is verb(q{feels})->past, q{felt}  => q{past 'feels' --> 'felt'};
is verb(q{ring})->past, q{rang}  => q{past 'ring' --> 'rang'};
is verb(q{provided})->past, q{provided}  => q{past 'provided' --> 'provided'};
is verb(q{irising})->past, q{irised}  => q{past 'irising' --> 'irised'};
is verb(q{flinging})->past, q{flung}  => q{past 'flinging' --> 'flung'};
is verb(q{changed})->past, q{changed}  => q{past 'changed' --> 'changed'};
is verb(q{wending})->past, q{wended}  => q{past 'wending' --> 'wended'};
is verb(q{live})->past, q{lived}  => q{past 'live' --> 'lived'};
is verb(q{finds})->past, q{found}  => q{past 'finds' --> 'found'};
is verb(q{choose})->past, q{chose}  => q{past 'choose' --> 'chose'};
is verb(q{gets})->past, q{got}  => q{past 'gets' --> 'got'};
is verb(q{knelt})->past, q{knelt}  => q{past 'knelt' --> 'knelt'};
is verb(q{shrinking})->past, q{shrank}  => q{past 'shrinking' --> 'shrank'};
is verb(q{dared})->past, q{dared}  => q{past 'dared' --> 'dared'};
is verb(q{seems})->past, q{seemed}  => q{past 'seems' --> 'seemed'};
is verb(q{rends})->past, q{rent}  => q{past 'rends' --> 'rent'};
is verb(q{killing})->past, q{killed}  => q{past 'killing' --> 'killed'};
is verb(q{driven})->past, q{drove}  => q{past 'driven' --> 'drove'};
is verb(q{lead})->past, q{led}  => q{past 'lead' --> 'led'};
is verb(q{beats})->past, q{beat}  => q{past 'beats' --> 'beat'};
is verb(q{spitting})->past, q{spat}  => q{past 'spitting' --> 'spat'};
is verb(q{skis})->past, q{skied}  => q{past 'skis' --> 'skied'};
is verb(q{fallen})->past, q{fell}  => q{past 'fallen' --> 'fell'};
is verb(q{understand})->past, q{understood}  => q{past 'understand' --> 'understood'};
is verb(q{rives})->past, q{rived}  => q{past 'rives' --> 'rived'};
is verb(q{will})->past, q{would}  => q{past 'will' --> 'would'};
is verb(q{sublets})->past, q{sublet}  => q{past 'sublets' --> 'sublet'};
is verb(q{_})->past, q{could}  => q{past '_' --> 'could'};
is verb(q{mistaking})->past, q{mistook}  => q{past 'mistaking' --> 'mistook'};
is verb(q{dying})->past, q{died}  => q{past 'dying' --> 'died'};
is verb(q{learning})->past, q{learned}  => q{past 'learning' --> 'learned'};
is verb(q{waiting})->past, q{waited}  => q{past 'waiting' --> 'waited'};
is verb(q{sawn})->past, q{sawed}  => q{past 'sawn' --> 'sawed'};
is verb(q{swings})->past, q{swung}  => q{past 'swings' --> 'swung'};
is verb(q{helps})->past, q{helped}  => q{past 'helps' --> 'helped'};
is verb(q{wake})->past, q{woke}  => q{past 'wake' --> 'woke'};
is verb(q{foreseen})->past, q{foresaw}  => q{past 'foreseen' --> 'foresaw'};
is verb(q{thrusting})->past, q{thrust}  => q{past 'thrusting' --> 'thrust'};
is verb(q{stands})->past, q{stood}  => q{past 'stands' --> 'stood'};
is verb(q{misleading})->past, q{misled}  => q{past 'misleading' --> 'misled'};
is verb(q{niche})->past, q{niched}  => q{past 'niche' --> 'niched'};
is verb(q{proven})->past, q{proved}  => q{past 'proven' --> 'proved'};
is verb(q{vexed})->past, q{vexed}  => q{past 'vexed' --> 'vexed'};
is verb(q{drinks})->past, q{drank}  => q{past 'drinks' --> 'drank'};
is verb(q{gives})->past, q{gave}  => q{past 'gives' --> 'gave'};
is verb(q{strived})->past, q{strove}  => q{past 'strived' --> 'strove'};
is verb(q{subletting})->past, q{sublet}  => q{past 'subletting' --> 'sublet'};
is verb(q{provides})->past, q{provided}  => q{past 'provides' --> 'provided'};
is verb(q{breaks})->past, q{broke}  => q{past 'breaks' --> 'broke'};
is verb(q{shoe})->past, q{shod}  => q{past 'shoe' --> 'shod'};
is verb(q{begins})->past, q{began}  => q{past 'begins' --> 'began'};
is verb(q{waits})->past, q{waited}  => q{past 'waits' --> 'waited'};
is verb(q{nicheing})->past, q{niched}  => q{past 'nicheing' --> 'niched'};
is verb(q{helping})->past, q{helped}  => q{past 'helping' --> 'helped'};
is verb(q{tear})->past, q{tore}  => q{past 'tear' --> 'tore'};
is verb(q{creched})->past, q{creched}  => q{past 'creched' --> 'creched'};
is verb(q{learn})->past, q{learned}  => q{past 'learn' --> 'learned'};
is verb(q{fought})->past, q{fought}  => q{past 'fought' --> 'fought'};
is verb(q{walked})->past, q{walked}  => q{past 'walked' --> 'walked'};
is verb(q{misunderstood})->past, q{misunderstood}  => q{past 'misunderstood' --> 'misunderstood'};
is verb(q{dies})->past, q{died}  => q{past 'dies' --> 'died'};
is verb(q{chooses})->past, q{chose}  => q{past 'chooses' --> 'chose'};
is verb(q{leap})->past, q{leapt}  => q{past 'leap' --> 'leapt'};
is verb(q{mislead})->past, q{misled}  => q{past 'mislead' --> 'misled'};
is verb(q{sped})->past, q{sped}  => q{past 'sped' --> 'sped'};
is verb(q{sunk})->past, q{sank}  => q{past 'sunk' --> 'sank'};

done_testing();
